<?php
/**
 * @package WordPress
 * @subpackage Sugical Directions
 */

/*
	--------------------------------------------
	Theme Support Settings
	--------------------------------------------
*/
	// global message return
	$wpMssg = array();

	$themeSettings = array(
		'taxonomies' => true,
		'imageSizes' => array(
			// array('name','width','height','crop');
			array('profile', 150, 215, true),
			array('client', 200, 124, true),
			array('thumb', 400, 320, true),
			array('page-width', 860, 640, true),
			array('page-width-narrow', 860, 320, true),
			array('social', 1024, 512, true),
			array('social-lrg', 1200, 600, true),
			array('full-screen', 1980, 1200, true),
			array('full-screen-medium', 1024, 1024, true),
			array('full-screen-small', 420, 600, true),
			array('full-screen-narrow', 1980, 800, true),
		),
		'styles' => array(
			array( 'font', "https://fonts.googleapis.com/css?family=Muli:400,400italic,300italic,300", '' ),
			array( 'screen', get_stylesheet_directory_uri()."/styles/screen.css", array('font')  ),
			array( 'screen-ie', get_stylesheet_directory_uri()."/styles/ie.css", array('screen')  ),
		),
		'scripts' => array(
			array( 'waypoints', get_template_directory_uri().'/libs/jquery.waypoints.min.js', array( 'jquery'), null, true),
			// array( 'svg4everybody', get_template_directory_uri().'/libs/svg4everybody.js', array( 'jquery'), null, true),
			array( 'counterup', get_template_directory_uri().'/libs/jquery.counterup.min.js', array( 'waypoints'), null, true),
			array( 'cycle2', get_template_directory_uri().'/libs/jquery.cycle2.min.js', array( 'jquery'), null, true),
			array( 'cycle_carousel', get_template_directory_uri().'/libs/jquery.cycle2.carousel.min.js', array( 'cycle2'), null, true),
		),
		'iniScript' => array('jquery'),
		'iniScriptHome' => array('jquery','counterup'),

		'postTypes' => array('open-positions','testimonials','resource','team','cta'),
		'metaScreens' =>array('open-positions','testimonials','resource','team','post','page'),
		'sidebars' => array('Footer Widgets','Page Default Sidebar','Blog Sidebar','Post Default Sidebar','Press Releases','Placements','Jobs','Team Members'),
		'menulist' => array('fourhunderedfour'    => __( '404' ),'main-menu'    => __( 'Main' ),'masthead'    => __( 'Masthead' ),'footer-menu'  => __( 'Footer' ),'page-sidebar' => __( 'Page Sidebar' ),'sitemap' => __( 'Site Map' )),
	);

	// Featured Image Settings
	if ( function_exists( 'add_theme_support' ) ) {	add_theme_support( 'post-thumbnails' ); }
	if ( function_exists( 'add_image_size' ) ) {
		foreach ($themeSettings['imageSizes'] as $image ) {
			add_image_size($image[0], $image[1], $image[2], $image[3]);
		}

	}
	if ( function_exists( 'add_image_size' ) ) {
		add_image_size('page-width', 860, 640, true);
		add_image_size('page-width-narrow', 860, 320, true);
	}
	add_filter('image_size_names_choose', 'my_image_sizes');
	function my_image_sizes($sizes) {
		$addsizes = array(
			"page-width"  => _("Page Width" ),
			"page-width-narrow"  => _("Page Width Narrow" ),
		);
		$newsizes = array_merge($sizes, $addsizes);
		return $newsizes;
	}
	add_action( 'wp_enqueue_scripts', 'enqueue_my_styles' );
	function enqueue_my_styles() {
		global $wp_styles;
		global $themeSettings;
		foreach ($themeSettings['styles'] as $style) {
			wp_enqueue_style( $style[0], $style[1], $style[2]  );
		}
		$wp_styles->add_data( 'screen-ie', 'conditional', 'lte IE 9' );
	}

	//Load JS Scripts
	function siteScriptLoad(){
		global $themeSettings;
		foreach ($themeSettings['scripts'] as $script) {
			wp_register_script( $script[0], $script[1],$script[2],$script[3],$script[4]);
		}

		foreach ($themeSettings['iniScript'] as $script) {
			wp_enqueue_script($script);
		}
		if(is_front_page()){
			foreach ($themeSettings['iniScriptHome'] as $script) {
				wp_enqueue_script($script);
			}
		}
	}
	add_action('wp_enqueue_scripts', 'siteScriptLoad');

	// Load CSS files


/*
	--------------------------------------------
	Includes for functions files
	--------------------------------------------
*/
	//Theme  Option Functions
	include get_template_directory().'/functions/theme.functions.php';
	include get_template_directory().'/functions/theme.options.php';
	include get_template_directory().'/functions/theme.scripts.php';

	// Misc Includes
	if($themeSettings['taxonomies']) {
		include get_template_directory().'/functions/taxonomies.php';
	}

	// Post Type Includes

	foreach ($themeSettings['postTypes'] as $post) {
		include get_template_directory().'/functions/post.'.$post.'.php';
	}

/*
	--------------------------------------------
	Include Template Loop and Part Functions
	--------------------------------------------
*/
	include get_template_directory().'/functions/template.parts.php';

	// Template Functions
	include get_template_directory().'/functions/template.resources.php';
	include get_template_directory().'/functions/template.archive.php';
	include get_template_directory().'/functions/template.team.php';
	include get_template_directory().'/functions/template.career.php';

	// Global Template Functions
	include get_template_directory().'/functions/template.functions.php';
	include get_template_directory().'/functions/template.sidebar.php';

	// Template Editors
	include get_template_directory().'/functions/template.front-page.php';
	include get_template_directory().'/functions/global.meta.php';
	remove_action('wp_head', 'rel_canonical');

	// Widget Includes
	include get_template_directory().'/functions/widget.classes.php';
	include get_template_directory().'/functions/widget.cta.php';
	include get_template_directory().'/functions/widget.social.php';

	include get_template_directory().'/functions/shortcodes.php';


/*
	--------------------------------------------
	Admin Panel Settings
	--------------------------------------------
*/

	// Load custom css for Meta Boxes

	add_action('admin_head', 'custom_postmeta');

	function custom_postmeta() {
		echo '<style>#postbox-container-2 .postbox label {width: 15%;float: left;}#postbox-container-1 .postbox label {width: 100%;float: left;}#postbox-container-1 .postbox label.checkbox {width: auto;float: none;}.imagepreview img{max-width: 545px;height: auto;margin: 10px 0;width: auto;}p{margin: 10px 0;}.hint{font-size: 14px;font-style: italic;width: 55%;margin: 5px 30% 5px 15%;display: inline-block;}.hint.noitalic{font-style: normal; font-size:14px;}.hint.after{width: auto;margin: 0 0 0 20px;display: inline;}.hint.error{color:red;}.hint .count{margin-right:20px;}p.desc {margin: 0 0 30px;font-size: .9em;}.seopreview{width: 512px;font-family: arial;padding: 10px;background: #efefef;margin: 0 0 0 15%;}.seopreview .title {white-space: nowrap;display: block;overflow: hidden;text-overflow: ellipsis;color: #1a0dab;font-size: 18px;line-height: 21.6px;}.seopreview .url {font-size: 14px;color: #006621;font-style: normal;line-height: 16px;}.seopreview .desc {overflow: hidden;width: 505px;font-size: 13px;color: #545454;line-height: 1.4;word-wrap: break-word;height: 51px;display: block;}</style>';
	}

/*
	--------------------------------------------
	Registrar Template Parts
	--------------------------------------------
*/

	// Register Menu Locations
	function register_my_menus() {
		global $themeSettings;
		$menulist = $themeSettings['menulist'];

		$cat = get_terms( 'page_categories', array('orderby' => 'id', 'hide_empty'=> false));

		foreach ($cat as $key => $value) {
			$menulist[$value->slug] = $value->name;
		}

		register_nav_menus($menulist);
	}
	add_action( 'init', 'register_my_menus' );

	// Register Sidebar Locations
	function register_my_sidebars() {
		global $themeSettings;
		$cat = get_terms( 'page_categories', array('orderby' => 'id', 'hide_empty'=> false));
		foreach ($cat as $key => $value) {
			$themeSettings['sidebars'][] = $value->name;
		}

		if ( function_exists('register_sidebar') ){

			foreach ($themeSettings['sidebars'] as $sidebar) {
				register_sidebar(
					array(
						'name'          => $sidebar,
						'before_widget' => '<div id="%1$s" class="widget %2$s">', // Removes <li>
						'after_widget'  => '</div>', // Removes </li>
						'before_title'  => '<h3 class="title">', // Replaces <h2>
						'after_title'   => '</h3>', // Replaces </h2>
					)
				);
			}
		}
	}
	add_action( 'init', 'register_my_sidebars' );

/*
	--------------------------------------------
	Global Functions
	--------------------------------------------
*/

	function trimString($string,$max=20) {
		$tok = strtok($string,' ');
		$sub = '';
		while($tok !== false && mb_strlen($sub) < $max) {
			if(strlen($sub) + mb_strlen($tok) <= $max) {
				$sub .= $tok.' ';
			} else {
				break;
			}
			$tok = strtok(' ');
		}
		$sub = trim($sub);
		$sube = $sub.'&hellip;';
		if(mb_strlen($sube) < mb_strlen($string)) $sub = $sube;
		return $sub;
	}

	// global html builder for CTAs
	function ctaBuilder($data){
		// $data = array('id' => 'var','title' => 'var','button_text' => 'var','url' => 'var','class' => 'var',);
		if(!isset($data['id'])) $data['id'] = 1;
		$html  = '<div class="'.$data['class'].' cta cta'.$data['id'].'">';
		$html .= '<h2 class="title"><a href="'.$data['url'].'">'.$data['title'].'</a></h2>';
		$html .= '<a class="button" href="'.$data['url'].'" target="'.$data['target'].'">'.$data['button_text'].'</a>';
		$html .= '</div>';

		return $html;
	}


	function getFooterCTAs($tags,$tax,$default){
		// $tag = array of matching tags
		// $count = how many to return
		// $build = if true returns html | false returns data array

		$args = array(
			'posts_per_page' => 1,
			'post_type'      => 'cta',
			'meta_key'       => 'cta_footer',
			'meta_value'     => 'true',
			'tax_query' => array(
				array(
					'taxonomy' => $tax,
					'field'    => 'slug',
					'terms'    => $tags,
				),
			),
		);

		if($default == true){
			$args = array(
				'posts_per_page' => 1,
				'post_type'      => 'cta',
				'meta_key'       => 'cta_footer_default',
				'meta_value'     => 'true',
			);

		}

		$ctas = array();

		$query = new WP_Query( $args );
		if (have_posts()) : while ($query->have_posts()) : $query->the_post();
			$ctameta = get_post_meta(get_the_ID());
			$ctas[] = array(
				'title'       => $ctameta['cta_text'][0],
				'button_text' => $ctameta['cta_button_text'][0],
				'url'         => $ctameta['cta_url'][0],
				'class'       => 'widget widget_cta '
			);

		endwhile;
	endif;
	wp_reset_postdata();

	return $ctas;
}

	// getTagged($tag,$count,$build);
function getTaggedCTAs($tags,$tax,$count,$build){
	// $tag = array of matching tags
	// $count = how many to return
	// $build = if true returns html | false returns data array

	$args = array(
		'posts_per_page' => $count,
		'post_type' => 'cta',
		'tax_query' => array(
			array(
				'taxonomy' => $tax,
				'field'    => 'slug',
				'terms'    => $tags,
			),
		),
	);

	$ctas = array();

	$query = new WP_Query( $args );
	if (have_posts()) : while ($query->have_posts()) : $query->the_post();
		$ctameta = get_post_meta(get_the_ID());
		$ctas[] = array(
			'title'       => $ctameta['cta_text'][0],
			'button_text' => $ctameta['cta_button_text'][0],
			'url'         => $ctameta['cta_url'][0],
			'class'       => 'widget widget_cta '
		);

	endwhile;
endif;
wp_reset_postdata();

if($build == true){
	$html = "";

	foreach ($ctas as $cta) {
		$html .= ctaBuilder($cta);
	}

	return $html;
}else{
	return $ctas;
}
}

function custom_excerpt_more( $more ) {
	return '';
}
add_filter( 'excerpt_more', 'custom_excerpt_more' );


function custom_pagination($numpages = '', $pagerange = '', $paged='') {

	if (empty($pagerange)) {
		$pagerange = 2;
	}

  /**
   * This first part of our function is a fallback
   * for custom pagination inside a regular loop that
   * uses the global $paged and global $wp_query variables.
   *
   * It's good because we can now override default pagination
   * in our theme, and use this function in default quries
   * and custom queries.
   */
  global $paged;
  if (empty($paged)) {
  	$paged = 1;
  }
  if ($numpages == '') {
  	global $wp_query;
  	$numpages = $wp_query->max_num_pages;
  	if(!$numpages) {
  		$numpages = 1;
  	}
  }

  /**
   * We construct the pagination arguments to enter into our paginate_links
   * function.
   */
  $pagination_args = array(
  	'base'            => get_pagenum_link(1) . '%_%',
  	'format'          => 'page/%#%',
  	'total'           => $numpages,
  	'current'         => $paged,
  	'show_all'        => False,
  	'end_size'        => 1,
  	'mid_size'        => $pagerange,
  	'prev_next'       => True,
  	'prev_text'       => __('&laquo;'),
  	'next_text'       => __('&raquo;'),
  	'type'            => 'plain',
  	'add_args'        => false,
  	'add_fragment'    => ''
  );

  $paginate_links = paginate_links($pagination_args);

  if ($paginate_links) {
  	echo "<div class='custom-pagination'>";
  	echo $paginate_links;
  	echo "</div>";
  }

}

function add_twitter_contactmethod( $contactmethods ) {
	if ( !isset( $contactmethods['googleplus'] ) )
		$contactmethods['googleplus'] = 'Goolge +';
	if ( !isset( $contactmethods['twitter'] ) )
		$contactmethods['twitter'] = 'Twitter';
	if ( !isset( $contactmethods['facebook'] ) )
		$contactmethods['facebook'] = 'Facebook';
	if ( !isset( $contactmethods['linkedin'] ) )
		$contactmethods['linkedin'] = 'LinkedIn';
	if ( !isset( $contactmethods['youtube'] ) )
		$contactmethods['youtube'] = 'YouTube';
	// Remove Yahoo IM
	if ( isset( $contactmethods['yim'] ) )
		unset( $contactmethods['yim'] );

	return $contactmethods;
}
add_filter( 'user_contactmethods', 'add_twitter_contactmethod', 10, 1 );

function namespace_add_custom_types( $query ) {
	if( is_category() || is_tag() && empty( $query->query_vars['suppress_filters'] ) ) {
		$query->set( 'post_type', array(
			'post', 'nav_menu_item', 'blog'
		));
		return $query;
	}
}
add_filter( 'pre_get_posts', 'namespace_add_custom_types' );

function svg($t,$u,$c){
	//set t to target #arrow leave $u empty to return default or set to path to svg
	//use $c to return class list
	if($u == 1) {$u = get_template_directory_uri().'/img/sprite.svg';}
	if($c == 0) {$c = "";}
	return '<svg class="'.$c.'"><use xlink:href="'.$u.$t.'"></use></svg>';
}

	//main menu functions

function menuCaseStudy($count){
	return '<div class="featimg size_page-width" style="background-image:url(http://surgicaldirections.localhost/wp-content/uploads/2016/01/shutterstock_339167573-860x640.jpg);"></div><div class="conwrap"><h3 class="title"><a href="http://surgicaldirections.localhost/resource/case-study-1/">Case Study 1</a></h3><p class="desc">Ut varius tincidunt libero. Vivamus aliquet elit ac nisl. Nam adipiscing. Curabitur vestibulum aliquam leo. Phasellus…</p><a class="readmore" href="http://surgicaldirections.localhost/resource/case-study-1/">Read More</a></div>';
}

function getContent($args){

	$query = new WP_Query( $args );
	$i =0;
		// The Loop
	if (have_posts()) : while ($query->have_posts()) : $query->the_post();
		$postId = $query->posts[$i]->ID;
		$card = "";

		$perma = get_post_meta( $postId, $args['perma'], true );
		if($perma == ""){$perma = get_permalink($postId);}

		if(has_post_thumbnail($postId)){
			$image_id = get_post_thumbnail_id($postId);
			$featimage = wp_get_attachment_image_src($image_id,$args['imageSize'], true)[0];
			$card .='<div class="featimg size_'.$args['imageSize'].'" style="background-image:url('.$featimage.');"></div>';
		}

		$card .='<div class="conwrap">';
		$card .= '<h2 class="title"><a href="'.$perma.'" >'.get_the_title().'</a></h2>';
		$card .= '<p class="desc">'.trimString(get_the_excerpt(),120).'</p>';
		$card .= '<a class="readmore" href="'.$perma.'">Read More</a>';
		$card .='</div>';
		$i++;
	endwhile;
endif;
wp_reset_postdata();

return $card;
}

function menuContent($type){

	$args = array(
		'posts_per_page' => 1,
		'post_type'      => 'resources',
		'meta_key'       => 'resources_featured',
		'meta_value'     => 'featured',
		'tax_query' => array(
			array('taxonomy'=>'resource_types','field'=>'slug','terms'=>'case-study'),
		)
	);

	switch ($type) {
		case 'casestudy':
		$args['tax_query'][0]['terms'] = 'case-study';
		break;
		case 'whitepaper':
		$args['tax_query'][0]['terms'] = 'whitepaper';
		break;
	}

	$content = '<div class="menucontent">';
	$content .= getContent($args);
	$content .= '</div>';

	return $content;
}

function tgm_io_shortcode_empty_paragraph_fix( $content ) {
	$array = array(
		'<p>['    => '[',
		']</p>'   => ']',
		'<p></p>'   => '',
		']<br />' => ']'
	);
	return strtr( $content, $array );
}

// Callback function to insert 'styleselect' into the $buttons array
function my_mce_buttons_2( $buttons ) {
	array_unshift( $buttons, 'styleselect' );
	return $buttons;
}
// Register our callback to the appropriate filter
add_filter( 'mce_buttons_2', 'my_mce_buttons_2' );

// Callback function to filter the MCE settings
function my_mce_before_init_insert_formats( $init_array ) {
	// Define the style_formats array
	$style_formats = array(
		// Each array child is a format with it's own settings
		array(
			'title' => 'Blue',
			'inline' => 'span',
			'classes' => 'bluelt',
			'wrapper' => true,

		),
		array(
			'title' => 'Green',
			'inline' => 'span',
			'classes' => 'green',
			'wrapper' => true,

		),
		array(
			'title' => 'Intro',
			'inline' => 'span',
			'classes' => 'intro',
			'wrapper' => true,
		),
		array(
			'title' => 'Button',
			'inline' => 'a',
			'classes' => 'button',
			'wrapper' => true,
		)
	);
	// Insert the array, JSON ENCODED, into 'style_formats'
	$init_array['style_formats'] = json_encode( $style_formats );

	return $init_array;

}
// Attach callback to 'tiny_mce_before_init'
add_filter( 'tiny_mce_before_init', 'my_mce_before_init_insert_formats' );

function my_theme_add_editor_styles() {
	$font_url = str_replace( ',', '%2C', '//fonts.googleapis.com/css?family=Muli:400,400italic,300italic,300' );
	add_editor_style( $font_url );
	add_editor_style( get_stylesheet_directory_uri()."/styles/admin.css" );
}
add_action( 'after_setup_theme', 'my_theme_add_editor_styles' );





/************* nav menu custom fields (for homepage anchor/smooth scroll) ***************/

/**
 * @package nav-menu-custom-fields
 * @version 0.1.0
 */
/*
Plugin Name: Nav Menu Custom Fields
*/

/*
 * Saves new field to postmeta for navigation
 */
add_action('wp_update_nav_menu_item', 'custom_nav_update',10, 3);
function custom_nav_update($menu_id, $menu_item_db_id, $args ) {
	if ( is_array($_REQUEST['menu-item-custom']) ) {
		$custom_value = $_REQUEST['menu-item-custom'][$menu_item_db_id];
		update_post_meta( $menu_item_db_id, '_menu_item_custom', $custom_value );
	}
}

/*
 * Adds value of new field to $item object that will be passed to     Walker_Nav_Menu_Edit_Custom
 */
add_filter( 'wp_setup_nav_menu_item','custom_nav_item' );
function custom_nav_item($menu_item) {
	$menu_item->custom = get_post_meta( $menu_item->ID, '_menu_item_custom', true );
	return $menu_item;
}

add_filter( 'wp_edit_nav_menu_walker', 'custom_nav_edit_walker',10,2 );
function custom_nav_edit_walker($walker,$menu_id) {
	return 'Walker_Nav_Menu_Edit_Custom';
}

/**
 * Copied from Walker_Nav_Menu_Edit class in core
 * 
 * Create HTML list of nav menu input items.
 *
 * @package WordPress
 * @since 3.0.0
 * @uses Walker_Nav_Menu
 */
class Walker_Nav_Menu_Edit_Custom extends Walker_Nav_Menu  {
/**
 * @see Walker_Nav_Menu::start_lvl()
 * @since 3.0.0
 *
 * @param string $output Passed by reference.
 */
function start_lvl(&$output) {}

/**
 * @see Walker_Nav_Menu::end_lvl()
 * @since 3.0.0
 *
 * @param string $output Passed by reference.
 */
function end_lvl(&$output) {
}

/**
 * @see Walker::start_el()
 * @since 3.0.0
 *
 * @param string $output Passed by reference. Used to append additional content.
 * @param object $item Menu item data object.
 * @param int $depth Depth of menu item. Used for padding.
 * @param object $args
 */
function start_el(&$output, $item, $depth, $args) {
	global $_wp_nav_menu_max_depth;
	$_wp_nav_menu_max_depth = $depth > $_wp_nav_menu_max_depth ? $depth : $_wp_nav_menu_max_depth;

	$indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';

	ob_start();
	$item_id = esc_attr( $item->ID );
	$removed_args = array(
		'action',
		'customlink-tab',
		'edit-menu-item',
		'menu-item',
		'page-tab',
		'_wpnonce',
	);

	$original_title = '';
	if ( 'taxonomy' == $item->type ) {
		$original_title = get_term_field( 'name', $item->object_id, $item->object, 'raw' );
		if ( is_wp_error( $original_title ) )
			$original_title = false;
	} elseif ( 'post_type' == $item->type ) {
		$original_object = get_post( $item->object_id );
		$original_title = $original_object->post_title;
	}

	$classes = array(
		'menu-item menu-item-depth-' . $depth,
		'menu-item-' . esc_attr( $item->object ),
		'menu-item-edit-' . ( ( isset( $_GET['edit-menu-item'] ) && $item_id == $_GET['edit-menu-item'] ) ? 'active' : 'inactive'),
	);

	$title = $item->title;

	if ( ! empty( $item->_invalid ) ) {
		$classes[] = 'menu-item-invalid';
		/* translators: %s: title of menu item which is invalid */
		$title = sprintf( __( '%s (Invalid)' ), $item->title );
	} elseif ( isset( $item->post_status ) && 'draft' == $item->post_status ) {
		$classes[] = 'pending';
		/* translators: %s: title of menu item in draft status */
		$title = sprintf( __('%s (Pending)'), $item->title );
	}

	$title = empty( $item->label ) ? $title : $item->label;

	?>
	<li id="menu-item-<?php echo $item_id; ?>" class="<?php echo implode(' ', $classes ); ?>">
		<dl class="menu-item-bar">
			<dt class="menu-item-handle">
				<span class="item-title"><?php echo esc_html( $title ); ?></span>
				<span class="item-controls">
					<span class="item-type"><?php echo esc_html( $item->type_label ); ?></span>
					<span class="item-order hide-if-js">
						<a href="<?php
						echo wp_nonce_url(
							add_query_arg(
								array(
									'action' => 'move-up-menu-item',
									'menu-item' => $item_id,
								),
								remove_query_arg($removed_args, admin_url( 'nav-menus.php' ) )
							),
							'move-menu_item'
						);
						?>" class="item-move-up"><abbr title="<?php esc_attr_e('Move up'); ?>">&#8593;</abbr></a>
						|
						<a href="<?php
						echo wp_nonce_url(
							add_query_arg(
								array(
									'action' => 'move-down-menu-item',
									'menu-item' => $item_id,
								),
								remove_query_arg($removed_args, admin_url( 'nav-menus.php' ) )
							),
							'move-menu_item'
						);
						?>" class="item-move-down"><abbr title="<?php esc_attr_e('Move down'); ?>">&#8595;</abbr></a>
					</span>
					<a class="item-edit" id="edit-<?php echo $item_id; ?>" title="<?php esc_attr_e('Edit Menu Item'); ?>" href="<?php
					echo ( isset( $_GET['edit-menu-item'] ) && $item_id == $_GET['edit-menu-item'] ) ? admin_url( 'nav-menus.php' ) : add_query_arg( 'edit-menu-item', $item_id, remove_query_arg( $removed_args, admin_url( 'nav-menus.php#menu-item-settings-' . $item_id ) ) );
					?>"><?php// _e( 'Edit Menu Item' ); ?></a>
				</span>
			</dt>
		</dl>

		<div class="menu-item-settings" id="menu-item-settings-<?php echo $item_id; ?>" style="float:left; margin-bottom:10px;">
			<?php if( 'custom' == $item->type ) : ?>
				<p class="field-url description description-wide">
					<label for="edit-menu-item-url-<?php echo $item_id; ?>">
						<?php _e( 'URL' ); ?><br />
						<input type="text" id="edit-menu-item-url-<?php echo $item_id; ?>" class="widefat code edit-menu-item-url" name="menu-item-url[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->url ); ?>" />
					</label>
				</p>
			<?php endif; ?>
			<p class="description description-thin">
				<label for="edit-menu-item-title-<?php echo $item_id; ?>">
					<?php _e( 'Navigation Label' ); ?><br />
					<input type="text" id="edit-menu-item-title-<?php echo $item_id; ?>" class="widefat edit-menu-item-title" name="menu-item-title[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->title ); ?>" />
				</label>
			</p>
			<p class="description description-thin">
				<label for="edit-menu-item-attr-title-<?php echo $item_id; ?>">
					<?php _e( 'Title Attribute' ); ?><br />
					<input type="text" id="edit-menu-item-attr-title-<?php echo $item_id; ?>" class="widefat edit-menu-item-attr-title" name="menu-item-attr-title[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->post_excerpt ); ?>" />
				</label>
			</p>
			<p class="field-link-target description">
				<label for="edit-menu-item-target-<?php echo $item_id; ?>">
					<input type="checkbox" id="edit-menu-item-target-<?php echo $item_id; ?>" value="_blank" name="menu-item-target[<?php echo $item_id; ?>]"<?php checked( $item->target, '_blank' ); ?> />
					<?php _e( 'Open link in a new window/tab' ); ?>
				</label>
			</p>
			<p class="field-css-classes description description-thin">
				<label for="edit-menu-item-classes-<?php echo $item_id; ?>">
					<?php _e( 'CSS Classes (optional)' ); ?><br />
					<input type="text" id="edit-menu-item-classes-<?php echo $item_id; ?>" class="widefat code edit-menu-item-classes" name="menu-item-classes[<?php echo $item_id; ?>]" value="<?php echo esc_attr( implode(' ', $item->classes ) ); ?>" />
				</label>
			</p>
			<p class="field-xfn description description-thin">
				<label for="edit-menu-item-xfn-<?php echo $item_id; ?>">
					<?php _e( 'Link Relationship (XFN)' ); ?><br />
					<input type="text" id="edit-menu-item-xfn-<?php echo $item_id; ?>" class="widefat code edit-menu-item-xfn" name="menu-item-xfn[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->xfn ); ?>" />
				</label>
			</p>
			<p class="field-description description description-wide">
				<label for="edit-menu-item-description-<?php echo $item_id; ?>">
					<?php _e( 'Description' ); ?><br />
					<textarea id="edit-menu-item-description-<?php echo $item_id; ?>" class="widefat edit-menu-item-description" rows="3" cols="20" name="menu-item-description[<?php echo $item_id; ?>]"><?php echo esc_html( $item->description ); // textarea_escaped ?></textarea>
					<span class="description"><?php _e('The description will be displayed in the menu if the current theme supports it.'); ?></span>
				</label>
			</p>        
			<?php
            /*
             * This is the added field
             */
            ?>      
            <p class="field-custom description description-wide">
            	<label for="edit-menu-item-custom-<?php echo $item_id; ?>">
            		<?php _e( 'Custom' ); ?><br />
            		<input type="text" id="edit-menu-item-custom-<?php echo $item_id; ?>" class="widefat code edit-menu-item-custom" name="menu-item-custom[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->custom ); ?>" />
            	</label>
            </p>
            <?php
            /*
             * end added field
             */
            ?>
            <div class="menu-item-actions description-wide submitbox">
            	<?php if( 'custom' != $item->type && $original_title !== false ) : ?>
            		<p class="link-to-original">
            			<?php printf( __('Original: %s'), '<a href="' . esc_attr( $item->url ) . '">' . esc_html( $original_title ) . '</a>' ); ?>
            		</p>
            	<?php endif; ?>
            	<a class="item-delete submitdelete deletion" id="delete-<?php echo $item_id; ?>" href="<?php
            	echo wp_nonce_url(
            		add_query_arg(
            			array(
            				'action' => 'delete-menu-item',
            				'menu-item' => $item_id,
            			),
            			remove_query_arg($removed_args, admin_url( 'nav-menus.php' ) )
            		),
            		'delete-menu_item_' . $item_id
            	); ?>"><?php _e('Remove'); ?></a> <span class="meta-sep"> | </span> <a class="item-cancel submitcancel" id="cancel-<?php echo $item_id; ?>" href="<?php echo esc_url( add_query_arg( array('edit-menu-item' => $item_id, 'cancel' => time()), remove_query_arg( $removed_args, admin_url( 'nav-menus.php' ) ) ) );
            	?>#menu-item-settings-<?php echo $item_id; ?>"><?php _e('Cancel'); ?></a>
            </div>

            <input class="menu-item-data-db-id" type="hidden" name="menu-item-db-id[<?php echo $item_id; ?>]" value="<?php echo $item_id; ?>" />
            <input class="menu-item-data-object-id" type="hidden" name="menu-item-object-id[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->object_id ); ?>" />
            <input class="menu-item-data-object" type="hidden" name="menu-item-object[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->object ); ?>" />
            <input class="menu-item-data-parent-id" type="hidden" name="menu-item-parent-id[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->menu_item_parent ); ?>" />
            <input class="menu-item-data-position" type="hidden" name="menu-item-position[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->menu_order ); ?>" />
            <input class="menu-item-data-type" type="hidden" name="menu-item-type[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->type ); ?>" />
        </div><!-- .menu-item-settings-->
        <ul class="menu-item-transport"></ul>
        <?php
        $output .= ob_get_clean();
    }
}