<?php

// ------------------------------------------------------
// Functions for Events
// ------------------------------------------------------

function event_post() {
	$labels = array(
		'name' => __( 'Events' ),
		'singular_name' => __( 'Event' ),
		'add_new' => __( 'New Event' ),
		'add_new_item' => __( 'Add New Event' ),
		'edit_item' => __( 'Edit Event' ),
		'new_item' => __( 'New Event' ),
		'view_item' => __( 'View Event' ),
		'search_items' => __( 'Search Events' ),
		'not_found' =>  __( 'No Events Found' ),
		'not_found_in_trash' => __( 'No Events found in Trash' ),
	);
	$args = array(
		'labels' => $labels,
		'has_archive' => false,
		'public' => true,
		'hierarchical' => false,
		'exclude_from_search'  => false,
        'menu_icon' => 'dashicons-calendar-alt',
		'supports' => array(
			'title',
			'editor',
			'excerpt',
			'thumbnail',
			'author',
		)
	);
	register_post_type( 'events', $args );
}
add_action( 'init', 'event_post' );

function event_option_metabox() {
	$screens = array( 'events');
	foreach ( $screens as $screen ) {
		add_meta_box(
			'event_option',
			__( 'Event Options', 'event_option_textdomain' ),
			'event_option_callback',
			$screen
		);
	}
}
add_action( 'add_meta_boxes', 'event_option_metabox' );

function event_option_callback( $post ) {
	wp_nonce_field( 'myplugin_meta_box', 'event_option_nonce' );

	$event_featured = get_post_meta( $post->ID, 'event_featured', true );
	$checked = "";
	if($event_featured == 'featured') $checked ='checked="checked"';
	echo '<p><input type="checkbox" id="event_featured" name="event_featured" value="featured" '.$checked.' /><label class="checkbox" for="event_featured">';
	_e( 'Set As Featured', 'event_featured_textdomain' );
	echo '</label></p>';

	$event_day = get_post_meta( $post->ID, 'event_day', true );
	echo '<p><label for="event_day">Day</label><input type="text" id="event_day" name="event_day" value="'.esc_attr( $event_day ).'" size="75" /></p>';

	$event_month = get_post_meta( $post->ID, 'event_month', true );
	echo '<p><label for="event_month">Month</label><input type="text" id="event_month" name="event_month" value="'.esc_attr( $event_month ).'" size="75" /></p>';

	$event_year = get_post_meta( $post->ID, 'event_year', true );
	echo '<p><label for="event_year">Year</label><input type="text" id="event_year" name="event_year" value="'.esc_attr( $event_year ).'" size="75" /></p>';

	$event_url = get_post_meta( $post->ID, 'event_url', true );
	echo '<p><label for="event_url">Url</label><input type="text" id="event_url" name="event_url" value="'.esc_attr( $event_url ).'" size="75" /></p>';

	$event_location = get_post_meta( $post->ID, 'event_location', true );
	echo '<p><label for="event_location">Location</label><input type="text" id="event_location" name="event_location" value="'.esc_attr( $event_location ).'" size="75" /></p>';

	$event_dir = get_post_meta( $post->ID, 'event_dir', true );
	echo '<p><label for="event_dir">Map URL </label><input type="text" id="event_dir" name="event_dir" value="'.esc_attr( $event_dir ).'" size="75" /></p>';
}

function event_option_save( $post_id ) {
	if ( ! isset( $_POST['event_option_nonce'] ) ) {return;}
	if ( ! wp_verify_nonce( $_POST['event_option_nonce'], 'myplugin_meta_box' ) ) {return;}
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {return;}
	if ( isset( $_POST['post_type'] ) && 'page' == $_POST['post_type'] ) {
		if ( ! current_user_can( 'edit_page', $post_id ) ) {return;}
	} else {
		if ( ! current_user_can( 'edit_post', $post_id ) ) {return;}
	}
	if (isset( $_POST['event_month'] ) ) {
		$my_data = sanitize_text_field( $_POST['event_month'] );
		update_post_meta( $post_id, 'event_month', $my_data );
	}
	if (isset( $_POST['event_day'] ) ) {
		$my_data = sanitize_text_field( $_POST['event_day'] );
		update_post_meta( $post_id, 'event_day', $my_data );
	}
	if (isset( $_POST['event_url'] ) ) {
		$my_data = sanitize_text_field( $_POST['event_url'] );
		update_post_meta( $post_id, 'event_url', $my_data );
	}
	if (isset( $_POST['event_year'] ) ) {
		$my_data = sanitize_text_field( $_POST['event_year'] );
		update_post_meta( $post_id, 'event_year', $my_data );
	}
	if (isset( $_POST['event_location'] ) ) {
		$my_data = sanitize_text_field( $_POST['event_location'] );
		update_post_meta( $post_id, 'event_location', $my_data );
	}
	if (isset( $_POST['event_dir'] ) ) {
		$my_data = sanitize_text_field( $_POST['event_dir'] );
		update_post_meta( $post_id, 'event_dir', $my_data );
	}

	if( isset( $_POST[ 'event_featured' ] ) ) {
    	update_post_meta( $post_id, 'event_featured', 'featured' );
	} else {
	    update_post_meta( $post_id, 'event_featured', 'false' );
	}

}
add_action( 'save_post', 'event_option_save' );
